pub fn current_anim() -> Option<AnimSpec>Expand description
The ambient animation set by the innermost enclosing with_animation, if any.
pub fn current_anim() -> Option<AnimSpec>The ambient animation set by the innermost enclosing with_animation, if any.