pub fn remove_frame_consumer(c: FrameConsumer)Expand description
Stop delivering frames to a consumer. When the last one is removed, the loop stops re-arming and the display link goes idle.
pub fn remove_frame_consumer(c: FrameConsumer)Stop delivering frames to a consumer. When the last one is removed, the loop stops re-arming and the display link goes idle.