pub fn register_menu_action(f: Rc<dyn Fn()>) -> u64Expand description
Register an app closure for a menu item and return its dispatch id (nonzero). The day-pieces
menu builder calls this while lowering a menu tree to the day_spec::MenuItem model.