pub fn set_toolbar(items: Vec<ToolbarItem>)Expand description
Install the toolbar on the window currently being built (the primary window outside a window
build). Replaces any previous toolbar on that window; an empty items removes it.
pub fn set_toolbar(items: Vec<ToolbarItem>)Install the toolbar on the window currently being built (the primary window outside a window
build). Replaces any previous toolbar on that window; an empty items removes it.